@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -21,7 +21,7 @@ GravatarDownloadPixmapWidget::GravatarDownloadPixmapWidget(QWidget *parent)
     auto mainLayout = new QVBoxLayout(this);
     auto hbox = new QHBoxLayout;
     mainLayout->addLayout(hbox);
-    QLabel *lab = new QLabel(i18n("Email:"));
+    auto lab = new QLabel(i18n("Email:"));
     lab->setObjectName(QStringLiteral("labemail"));
     hbox->addWidget(lab);
     mLineEdit = new QLineEdit;
@@ -51,9 +51,7 @@ GravatarDownloadPixmapWidget::GravatarDownloadPixmapWidget(QWidget *parent)
     mainLayout->addWidget(mResultLabel);
 }
 
-GravatarDownloadPixmapWidget::~GravatarDownloadPixmapWidget()
-{
-}
+GravatarDownloadPixmapWidget::~GravatarDownloadPixmapWidget() = default;
 
 QPixmap GravatarDownloadPixmapWidget::gravatarPixmap() const
 {
@@ -95,3 +93,5 @@ void GravatarDownloadPixmapWidget::slotTextChanged(const QString &text)
 {
     mGetPixmapButton->setEnabled(!text.trimmed().isEmpty());
 }
+
+#include "moc_gravatardownloadpixmapwidget.cpp"
